# Security Policy

## Supported Versions

Only the latest stable version and the version under development are supported.

|        Version        |   Supported   |
| :-------------------: | :-----------: |
|  Development version  |      OK       |
| Latest Stable version |      OK       |
|    Other versions     | Not supported |

## Reporting a Vulnerability

In general, there are no security vulnerabilities and other related issues in this project. But if so, please also contact the maintainers of this project in a private way or just [report a security vulnerability](https://github.com/Xiaokang2022/maliang/security/advisories/new), thank you!
